@@ -139,8 +139,8 @@ impl GeneralReadout for AndroidGeneralReadout {
         Ok(version)
     }
 
-    fn local_ip(&self) -> Result<String, ReadoutError> {
-        crate::shared::local_ip()
+    fn local_ip(&self, interface: String) -> Result<String, ReadoutError> {
+        crate::shared::local_ip(interface)
     }
 
     fn username(&self) -> Result<String, ReadoutError> {
